import { Command } from 'ckeditor5/src/core';
import { first } from 'ckeditor5/src/utils';

export default class InlineRelatedPostCommand extends Command {
  execute( { value, drupalField, url} ) {
    const editor = this.editor;
    const selection = editor.model.document.selection;


    editor.model.change( writer => {
      // Create a <inline-related-post> element with the "name","drupalField" and url
      // attribute (and all the selection attributes)...
      const inlineRelatedPost = writer.createElement( 'inline-related-post', {
        ...Object.fromEntries( selection.getAttributes() ),
        'data-related-post-id': value,
        'data-related-url': url,
        'data-drupal-field' : drupalField
      } );

      // ... and insert it into the document. Put the selection on the inserted element.
      editor.model.insertObject( inlineRelatedPost, null, null, { setSelection: 'on' } );
    });
  }

  refresh() {
    const model = this.editor.model;
    const selection = model.document.selection;
    var field_related_links = false
    if (this.editor.config._config.InlineRelatedPost.options) {
      field_related_links = document.querySelectorAll('[name^=' + this.editor.config._config.InlineRelatedPost.options[0] + '][name$="[uri]"]:not([value=""])').length > 0
    }


    // If inline
    // const isAllowed = model.schema.checkChild( selection.focus.parent, 'inline-related-post' );
    // this.isEnabled = isAllowed;

    // If block
    const allowedIn = model.schema.findAllowedParent( selection.getFirstPosition(), 'inline-related-post' );
    this.isEnabled = (allowedIn !== null) && field_related_links;
  }
}

