import { Plugin } from 'ckeditor5/src/core';
import { addListToDropdown, createDropdown, ViewModel } from 'ckeditor5/src/ui';
import { Collection } from 'ckeditor5/src/utils';
import icon from '../../../../icons/inline-related-post.svg';

export default class InlineRelatedPostUI extends Plugin {
  init() {
    const editor = this.editor;
    const t = editor.t;

    const itemDefinitions = new Collection();

    for (let definedField of editor.config._config.InlineRelatedPost.options) {
      const fieldRelatedLinks = document.querySelectorAll('[name^=' + definedField + '][name$="[uri]"]:not([value=""])')
      // foreach if not empty i agafar titol pel select.
      for (const [key, related_link] of Object.entries(fieldRelatedLinks)){
        if (related_link.value) {
          const definition = {
            type: 'button',
            model: new ViewModel( {
              commandParam: key,
              drupalField: definedField,
              url: related_link.value,
              label: `${definedField}[${key}]: ${related_link.value}`,
              withText: true
            } )
          };

          // Add the item definition to the collection.
          itemDefinitions.add( definition );
        }
      }
    }
    //const inlineRelatedPostNames = field_related_links.keys() || [...Array(10).keys()];

    // The "inlineRelatedPost" dropdown must be registered among the UI components of the editor
    // to be displayed in the toolbar.
    editor.ui.componentFactory.add( 'inlineRelatedPost', locale => {
      const dropdownView = createDropdown( locale );

      // Populate the list in the dropdown with items.
      addListToDropdown( dropdownView, itemDefinitions);

      dropdownView.buttonView.set( {
        // The t() function helps localize the editor. All strings enclosed in t() can be
        // translated and change when the language of the editor changes.
        label: t( 'Inline Related Post' ),
        icon: icon,
        tooltip: true,
      } );

      // Disable the inline-related-post button when the command is disabled.
      const command = editor.commands.get( 'inline-related-post' );
      dropdownView.bind( 'isEnabled' ).to( command );

      this.listenTo(editor.model.document, 'change:data',() => {
        // TODO refresh the items in dropdown
      })


      // Execute the command when the dropdown item is clicked (executed).
      this.listenTo( dropdownView, 'execute', evt => {
        console.log(evt)
        editor.execute( 'inline-related-post', {
          value: evt.source.commandParam,
          drupalField: evt.source.drupalField,
          url: evt.source.url
        });
        editor.editing.view.focus();
      } );

      return dropdownView;
    } );
  }
}

